/*
  ZUNO_HDC1080.h v.1.01- Arduino library support for Temp./Humidity sensor TI HDC1080
  - basic version -
  Copyright (C)2018 SmartHome.Work, Michael Pruefer. All right reserved
  
  This library has been made to make it easy to use the HDC1080 chip.
  Chip maybe integrated at CCS811 module for temperature/humidity compensation of
  CCS811  chip, then library could be included here.
  
  Based on the TI datasheet http://www.ti.com/lit/ds/symlink/hdc1080.pdf.
  Tested with Z-Uno and CCS811 module CJMCU-8128

  Permission is hereby granted, free of charge, to any person obtaining a copy of
  this software and associated documentation files (the "Software"), to deal in
  the Software without restriction, including without limitation the rights to use,
  copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the 
  Software, and to permit persons to whom the Software is furnished to do so,
  subject to the following conditions:

  The above copyright notice and this permission notice shall be included 
  in all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS 
  FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR 
  COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER 
  IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION 
  WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. 
*/

#ifndef ZUNO_HDC1080_h
#define ZUNO_HDC1080_h

#define HDC1080_REG_CONFIG     		0x02
#define HDC1080_REG_TEMP			0x00
#define HDC1080_REG_HUM				0x01


#define REG_TEMP_LOW 				0x00
#define REG_TEMP_HIGH 				0x01
#define REG_HUM_LOW 				0x02
#define REG_HUM_HIGH 				0x03

#define HDC1080_SOFT_RESET			0x80

#include "Arduino.h"

class HDC1080
{
	public:
		HDC1080(uint8_t addr);					// Initialize the HDC2010
		void begin(void);  						// Join I2C bus
		void defaultInit(void);					// Software reset and default resolution sensors to 14bit
		void setTempRes(int resolution);		// Set resolution for temperature sensor (14|11)
		void setHumidRes(int resolution);		// Set resolution for humidity sensor (14|11|8)
		void readAllValues(void);				// Read temperature and humidity values together into array
		float readTemp(void);					// Returns the temperature in degrees C
		float readHum(void);				// Returns the relative humidity
		
	private:
		int _addr; 									// Address of sensor 
		void hdc_readn(byte reg, byte n);			// Read n bytes of data from register to HDC1080_tdata[i]
		void hdc_writeReg(byte reg, byte n);			// Writes n bytes of data from HDC1080_tdata[i] to register

};


#endif